@@ -26,11 +26,9 @@
 
 ImportImapSettingProgressPage::ImportImapSettingProgressPage(QWidget *parent)
     : QWidget(parent)
-    , mSettingsFound(false)
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainlayout"));
-    mainLayout->setContentsMargins(0, 0, 0, 0);
     mProgressTextEdit = new QTextEdit(this);
     mProgressTextEdit->setObjectName(QStringLiteral("textedit"));
     mProgressTextEdit->setReadOnly(true);
